@@ -17,9 +17,9 @@ use constant _F_ELEMENTS  => 5;     # elements arrayref
 use constant _F_ROTATORS  => 6;     # rotators arrayref, initially empty
 use constant _NFIELDS     => 7;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
-our $_MAX_ENUM_ORDER = 1024;
+our $_MAX_ENUM_COUNT = 32768;
 our $_LOG_MAX_ORDER = 21 * log(2);
 
 my $DATA = undef;
@@ -47,7 +47,7 @@ sub _rotators {
     my (           $base,   $exponent,   $modulus,   $rotators) =
         @{$this}[_F_BASE, _F_EXPONENT, _F_MODULUS, _F_ROTATORS];
     return $rotators if @{$rotators};
-    return undef if $this->[_F_ORDER] > $_MAX_ENUM_ORDER;
+    return undef if $this->[_F_N_PLANES] > $_MAX_ENUM_COUNT;
     my @mult = _multipliers($base, $exponent, $modulus);
     my @sieve = (1) x $modulus;
     @sieve[@mult] = ();
@@ -379,7 +379,7 @@ Math::DifferenceSet::Planar - object class for planar difference sets
 
 =head1 VERSION
 
-This documentation refers to version 0.005 of Math::DifferenceSet::Planar.
+This documentation refers to version 0.006 of Math::DifferenceSet::Planar.
 
 =head1 SYNOPSIS
 
